ASSET is a dataset for evaluating Sentence Simplification systems with multiple
rewriting transformations, as described in "ASSET: A Dataset for Tuning and
Evaluation of Sentence Simplification Models with Multiple Rewriting
Transformations." The corpus is composed of 2000 validation and 359 test
original sentences that were each simplified 10 times by different annotators.
The corpus also contains human judgments of meaning preservation, fluency and
simplicity for the outputs of several automatic text simplification systems.
